Package: smoothbp
Title: Hierarchical Piecewise Regression with Smoothed Change-Points
Version: 0.2.7
Date: 2026-06-15
Authors@R: 
    person("Aidan D", "Bindoff", , "aidan.bindoff@utas.edu.au", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-0943-2702"))
Description: Fits Bayesian hierarchical piecewise regression models with 
    multiple logistic-smoothed change-points. Non-linear parameters (change-point 
    locations and transition sharpness) and linear parameters can each be 
    conditioned on covariates and factors via flexible design matrices. 
    A random-intercept structure is supported for any parameter. Spike-and-slab 
    regularization is supported for selecting the number of breakpoints. 
    Posterior inference uses a Metropolis-within-Gibbs sampler implemented 
    in 'Rust' for speed. Methods are based on the smooth transition 
    piecewise regression model of Bacon and Watts (1971) <doi:10.2307/2334389> 
    and variable selection spike-and-slab priors of Kuo and Mallick (1998) 
    <https://www.jstor.org/stable/25053023>.
License: MIT + file LICENSE
Encoding: UTF-8
Language: en-GB
RoxygenNote: 7.3.3
Config/rextendr/version: 0.5.0
SystemRequirements: Cargo (Rust's package manager), rustc >= 1.65.0
Depends: R (>= 4.2)
Imports: posterior, ggplot2, stats, bridgesampling, loo, bayesplot
Suggests: testthat (>= 3.0.0), withr, knitr, rmarkdown, brms, mcp,
        dplyr, gt, tidyr, scales, rjags
Config/testthat/edition: 3
VignetteBuilder: knitr
URL: https://github.com/ABindoff/smoothbp
BugReports: https://github.com/ABindoff/smoothbp/issues
NeedsCompilation: yes
Packaged: 2026-06-15 22:47:33 UTC; bindoffa
Author: Aidan D Bindoff [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0943-2702>)
Maintainer: Aidan D Bindoff <aidan.bindoff@utas.edu.au>
Repository: CRAN
Date/Publication: 2026-06-16 07:20:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-06-16 09:14:12 UTC; unix
Archs: smoothbp.so.dSYM
