# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,smoothbp_fit)
S3method(bayes_factor,smoothbp_fit)
S3method(bridge_sampler,smoothbp_fit)
S3method(derivative,smoothbp_fit)
S3method(derivative,smoothbp_ss_fit)
S3method(fitted,smoothbp_fit)
S3method(hypothesis,smoothbp_fit)
S3method(log_lik,smoothbp_fit)
S3method(loo,smoothbp_fit)
S3method(model_methods,smoothbp_fit)
S3method(model_results,smoothbp_fit)
S3method(pip,smoothbp_ss_fit)
S3method(plot,smoothbp_fit)
S3method(plot,smoothbp_pip)
S3method(pp_check,smoothbp_fit)
S3method(print,smoothbp_fit)
S3method(print,smoothbp_hypothesis)
S3method(print,smoothbp_pip)
S3method(print,smoothbp_prior)
S3method(print,smoothbp_priors)
S3method(print,smoothbp_spike_slab)
S3method(print,smoothbp_ss_fit)
S3method(robustify,smoothbp_fit)
S3method(summary,smoothbp_fit)
S3method(summary,smoothbp_ss_fit)
S3method(update,smoothbp_fit)
S3method(waic,smoothbp_fit)
export(derivative)
export(fixed)
export(hypothesis)
export(log_lik)
export(loo)
export(model_methods)
export(model_results)
export(pip)
export(pp_check)
export(prior_gamma)
export(prior_invgamma)
export(prior_normal)
export(prior_spike_slab)
export(recovery_plot)
export(robustify)
export(simulate_smoothbp)
export(smoothbp)
export(smoothbp_priors)
export(smoothbp_ss)
export(space_omega_priors)
export(tab_smoothbp)
export(trace_plot)
export(true_params)
export(waic)
importFrom(bayesplot,pp_check)
importFrom(bridgesampling,bayes_factor)
importFrom(bridgesampling,bridge_sampler)
importFrom(loo,loo)
importFrom(loo,waic)
importFrom(stats,dnorm)
importFrom(stats,fitted)
importFrom(stats,rnorm)
importFrom(stats,setNames)
importFrom(stats,terms)
useDynLib(smoothbp, .registration = TRUE)
