# Generated by extendr: Do not edit by hand
# nolint start

#' @usage NULL
#' @useDynLib smoothbp, .registration = TRUE
NULL

#' @noRd
#' @keywords internal
run_mcmc <- function(y, tau, x_b0, p_b0, x_b1, p_b1, x_deltas, p_deltas, x_om, p_om, x_rho, p_rho, group_b0, n_groups_b0, prior_mean_b0, prior_sd_b0, prior_lb_b0, prior_ub_b0, prior_mean_b1, prior_sd_b1, prior_lb_b1, prior_ub_b1, prior_mean_deltas, prior_sd_deltas, prior_lb_deltas, prior_ub_deltas, prior_mean_om, prior_sd_om, prior_lb_om, prior_ub_om, prior_mean_rho, prior_sd_rho, prior_lb_rho, prior_ub_rho, sigma_shape, sigma_scale, sigma_u_shape, sigma_u_scale, step_om, step_rho, target_accept, chains, iter, warmup, seed, verbose, n_cores) .Call(wrap__run_mcmc, y, tau, x_b0, p_b0, x_b1, p_b1, x_deltas, p_deltas, x_om, p_om, x_rho, p_rho, group_b0, n_groups_b0, prior_mean_b0, prior_sd_b0, prior_lb_b0, prior_ub_b0, prior_mean_b1, prior_sd_b1, prior_lb_b1, prior_ub_b1, prior_mean_deltas, prior_sd_deltas, prior_lb_deltas, prior_ub_deltas, prior_mean_om, prior_sd_om, prior_lb_om, prior_ub_om, prior_mean_rho, prior_sd_rho, prior_lb_rho, prior_ub_rho, sigma_shape, sigma_scale, sigma_u_shape, sigma_u_scale, step_om, step_rho, target_accept, chains, iter, warmup, seed, verbose, n_cores)

#' @noRd
#' @keywords internal
run_mcmc_ss <- function(y, tau, x_b0, p_b0, x_b1, p_b1, x_deltas, p_deltas, x_om, p_om, x_rho, p_rho, group_b0, n_groups_b0, prior_mean_b0, prior_sd_b0, prior_lb_b0, prior_ub_b0, prior_mean_b1, prior_sd_b1, prior_lb_b1, prior_ub_b1, prior_mean_deltas, prior_sd_deltas, prior_lb_deltas, prior_ub_deltas, prior_mean_om, prior_sd_om, prior_lb_om, prior_ub_om, prior_mean_rho, prior_sd_rho, prior_lb_rho, prior_ub_rho, sigma_shape, sigma_scale, sigma_u_shape, sigma_u_scale, step_om, step_rho, target_accept, b1_spike_mask, delta_spike_mask, pi_init, pi_beta_a, pi_beta_b, chains, iter, warmup, seed, verbose, n_cores) .Call(wrap__run_mcmc_ss, y, tau, x_b0, p_b0, x_b1, p_b1, x_deltas, p_deltas, x_om, p_om, x_rho, p_rho, group_b0, n_groups_b0, prior_mean_b0, prior_sd_b0, prior_lb_b0, prior_ub_b0, prior_mean_b1, prior_sd_b1, prior_lb_b1, prior_ub_b1, prior_mean_deltas, prior_sd_deltas, prior_lb_deltas, prior_ub_deltas, prior_mean_om, prior_sd_om, prior_lb_om, prior_ub_om, prior_mean_rho, prior_sd_rho, prior_lb_rho, prior_ub_rho, sigma_shape, sigma_scale, sigma_u_shape, sigma_u_scale, step_om, step_rho, target_accept, b1_spike_mask, delta_spike_mask, pi_init, pi_beta_a, pi_beta_b, chains, iter, warmup, seed, verbose, n_cores)

#' @noRd
#' @keywords internal
run_mcmc_re <- function(y, tau, x_b0, p_b0, x_b1, p_b1, x_deltas, p_deltas, x_om, p_om, x_rho, p_rho, group_b0, n_groups_b0, re_mask_om, nc_om_per_group, re_mask_b1, re_mask_deltas, nc_b1, nc_deltas, group_re, n_subjects, prior_mean_b0, prior_sd_b0, prior_lb_b0, prior_ub_b0, prior_mean_b1, prior_sd_b1, prior_lb_b1, prior_ub_b1, prior_mean_deltas, prior_sd_deltas, prior_lb_deltas, prior_ub_deltas, prior_mean_om, prior_sd_om, prior_lb_om, prior_ub_om, prior_mean_rho, prior_sd_rho, prior_lb_rho, prior_ub_rho, sigma_shape, sigma_scale, sigma_u_shape, sigma_u_scale, sigma_re_om_shape, sigma_re_om_scale, sigma_re_b1_shape, sigma_re_b1_scale, sigma_re_deltas_shape, sigma_re_deltas_scale, step_om, step_rho, target_accept, chains, iter, warmup, seed, verbose, n_cores) .Call(wrap__run_mcmc_re, y, tau, x_b0, p_b0, x_b1, p_b1, x_deltas, p_deltas, x_om, p_om, x_rho, p_rho, group_b0, n_groups_b0, re_mask_om, nc_om_per_group, re_mask_b1, re_mask_deltas, nc_b1, nc_deltas, group_re, n_subjects, prior_mean_b0, prior_sd_b0, prior_lb_b0, prior_ub_b0, prior_mean_b1, prior_sd_b1, prior_lb_b1, prior_ub_b1, prior_mean_deltas, prior_sd_deltas, prior_lb_deltas, prior_ub_deltas, prior_mean_om, prior_sd_om, prior_lb_om, prior_ub_om, prior_mean_rho, prior_sd_rho, prior_lb_rho, prior_ub_rho, sigma_shape, sigma_scale, sigma_u_shape, sigma_u_scale, sigma_re_om_shape, sigma_re_om_scale, sigma_re_b1_shape, sigma_re_b1_scale, sigma_re_deltas_shape, sigma_re_deltas_scale, step_om, step_rho, target_accept, chains, iter, warmup, seed, verbose, n_cores)

#' @noRd
#' @keywords internal
run_mcmc_re_ss <- function(y, tau, x_b0, p_b0, x_b1, p_b1, x_deltas, p_deltas, x_om, p_om, x_rho, p_rho, group_b0, n_groups_b0, re_mask_om, nc_om_per_group, re_mask_b1, re_mask_deltas, nc_b1, nc_deltas, group_re, n_subjects, prior_mean_b0, prior_sd_b0, prior_lb_b0, prior_ub_b0, prior_mean_b1, prior_sd_b1, prior_lb_b1, prior_ub_b1, prior_mean_deltas, prior_sd_deltas, prior_lb_deltas, prior_ub_deltas, prior_mean_om, prior_sd_om, prior_lb_om, prior_ub_om, prior_mean_rho, prior_sd_rho, prior_lb_rho, prior_ub_rho, hyper_priors, step_om, step_rho, target_accept, b1_spike_mask, delta_spike_mask, pi_init, pi_beta_a, pi_beta_b, mcmc_control) .Call(wrap__run_mcmc_re_ss, y, tau, x_b0, p_b0, x_b1, p_b1, x_deltas, p_deltas, x_om, p_om, x_rho, p_rho, group_b0, n_groups_b0, re_mask_om, nc_om_per_group, re_mask_b1, re_mask_deltas, nc_b1, nc_deltas, group_re, n_subjects, prior_mean_b0, prior_sd_b0, prior_lb_b0, prior_ub_b0, prior_mean_b1, prior_sd_b1, prior_lb_b1, prior_ub_b1, prior_mean_deltas, prior_sd_deltas, prior_lb_deltas, prior_ub_deltas, prior_mean_om, prior_sd_om, prior_lb_om, prior_ub_om, prior_mean_rho, prior_sd_rho, prior_lb_rho, prior_ub_rho, hyper_priors, step_om, step_rho, target_accept, b1_spike_mask, delta_spike_mask, pi_init, pi_beta_a, pi_beta_b, mcmc_control)

#' @noRd
#' @keywords internal
run_bridge <- function(y, tau, x_b0, p_b0, x_b1, p_b1, x_deltas, p_deltas, x_om, p_om, x_rho, p_rho, group_b0, n_groups_b0, prior_mean_b0, prior_sd_b0, prior_lb_b0, prior_ub_b0, prior_mean_b1, prior_sd_b1, prior_lb_b1, prior_ub_b1, prior_mean_deltas, prior_sd_deltas, prior_lb_deltas, prior_ub_deltas, prior_mean_om, prior_sd_om, prior_lb_om, prior_ub_om, prior_mean_rho, prior_sd_rho, prior_lb_rho, prior_ub_rho, sigma_shape, sigma_scale, sigma_u_shape, sigma_u_scale, mcmc_draws, seed) .Call(wrap__run_bridge, y, tau, x_b0, p_b0, x_b1, p_b1, x_deltas, p_deltas, x_om, p_om, x_rho, p_rho, group_b0, n_groups_b0, prior_mean_b0, prior_sd_b0, prior_lb_b0, prior_ub_b0, prior_mean_b1, prior_sd_b1, prior_lb_b1, prior_ub_b1, prior_mean_deltas, prior_sd_deltas, prior_lb_deltas, prior_ub_deltas, prior_mean_om, prior_sd_om, prior_lb_om, prior_ub_om, prior_mean_rho, prior_sd_rho, prior_lb_rho, prior_ub_rho, sigma_shape, sigma_scale, sigma_u_shape, sigma_u_scale, mcmc_draws, seed)

# nolint end
