% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/priors.R
\name{prior_normal}
\alias{prior_normal}
\title{Specify a normal (or truncated normal) prior for a regression coefficient}
\usage{
prior_normal(mean = 0, sd = 1, lb = -Inf, ub = Inf)
}
\arguments{
\item{mean}{Prior mean. Default 0.}

\item{sd}{Prior standard deviation. Default 1.}

\item{lb}{Lower bound (use \code{-Inf} for unconstrained). Default \code{-Inf}.}

\item{ub}{Upper bound (use \code{Inf} for unconstrained). Default \code{Inf}.}
}
\value{
A \code{smoothbp_prior} object.
}
\description{
Specify a normal (or truncated normal) prior for a regression coefficient
}
