% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/priors.R
\name{prior_invgamma}
\alias{prior_invgamma}
\title{Specify an inverse-gamma prior for a variance component}
\usage{
prior_invgamma(shape = 1, scale = 1)
}
\arguments{
\item{shape}{Shape parameter (> 0).}

\item{scale}{Scale parameter (> 0).}
}
\value{
A \code{smoothbp_prior} object.
}
\description{
Specify an inverse-gamma prior for a variance component
}
