% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/robustify.R
\name{robustify}
\alias{robustify}
\title{Robustify a smoothbp_fit object using a Bayesian Sandwich approach}
\usage{
robustify(object, cluster, ...)
}
\arguments{
\item{object}{A \code{smoothbp_fit} object.}

\item{cluster}{String naming the column in \code{object$data} defining the clusters (e.g., Subject ID).}

\item{...}{Unused.}
}
\value{
A new \code{smoothbp_fit} object where the MCMC draws have been affinely transformed to match the robust clustered covariance matrix.
}
\description{
Robustify a smoothbp_fit object using a Bayesian Sandwich approach
}
