% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_methods.R
\name{plot.smoothbp_pip}
\alias{plot.smoothbp_pip}
\title{Plot posterior inclusion probabilities}
\usage{
\method{plot}{smoothbp_pip}(x, ...)
}
\arguments{
\item{x}{A \code{smoothbp_pip} object.}

\item{...}{Unused.}
}
\value{
A \code{ggplot} object.
}
\description{
Plot posterior inclusion probabilities
}
