% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/priors.R
\name{prior_gamma}
\alias{prior_gamma}
\title{Specify a gamma prior for a parameter}
\usage{
prior_gamma(shape = 1, scale = 1)
}
\arguments{
\item{shape}{Shape parameter (> 0).}

\item{scale}{Scale parameter (> 0).}
}
\value{
A \code{smoothbp_prior} object.
}
\description{
Specify a gamma prior for a parameter
}
