% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/generics.R, R/postprocess.R
\name{log_lik}
\alias{log_lik}
\alias{log_lik.smoothbp_fit}
\title{Pointwise log-likelihood matrix}
\usage{
log_lik(object, ...)

\method{log_lik}{smoothbp_fit}(object, ...)
}
\arguments{
\item{object}{A \code{smoothbp_fit} object.}

\item{...}{Unused.}
}
\value{
A matrix of pointwise log-likelihood values of dimension \code{S x N},
where \code{S} is the number of posterior draws and \code{N} is the number
of observations.
}
\description{
Pointwise log-likelihood matrix
}
