% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/postprocess_ss.R
\name{pip}
\alias{pip}
\title{Posterior inclusion probabilities from a spike-and-slab fit}
\usage{
pip(object, ...)
}
\arguments{
\item{object}{A \code{smoothbp_ss_fit} object.}

\item{...}{Ignored.}
}
\value{
A named numeric vector of posterior inclusion probabilities (PIPs)
for each b2 coefficient that had a spike-and-slab prior.
}
\description{
Posterior inclusion probabilities from a spike-and-slab fit
}
