% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simulate.R
\name{true_params}
\alias{true_params}
\title{Print true parameters from a simulated dataset}
\usage{
true_params(dat)
}
\arguments{
\item{dat}{A \code{data.frame} returned by \code{simulate_smoothbp}.}
}
\value{
The \code{true_params} list, invisibly.
}
\description{
Convenience function to display the data-generating parameters stored in the
\code{"true_params"} attribute of a dataset returned by
\code{\link{simulate_smoothbp}}.
}
