% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{round_df}
\alias{round_df}
\title{Round numeric columns in a data frame}
\usage{
round_df(df, digits = 3)
}
\description{
Round numeric columns in a data frame
}
\keyword{internal}
