% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/postprocess.R
\name{as.data.frame.smoothbp_fit}
\alias{as.data.frame.smoothbp_fit}
\title{Convert draws to a data frame}
\usage{
\method{as.data.frame}{smoothbp_fit}(x, ...)
}
\arguments{
\item{x}{A \code{smoothbp_fit} object.}

\item{...}{Passed to \code{as.data.frame.draws_df}.}
}
\value{
A \code{data.frame} containing the posterior draws of the model parameters.
}
\description{
Convert draws to a data frame
}
