% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bridge_sampling.R
\name{bayes_factor.smoothbp_fit}
\alias{bayes_factor.smoothbp_fit}
\title{Bayes Factor for smoothbp_fit}
\usage{
\method{bayes_factor}{smoothbp_fit}(x1, x2, log = FALSE, ...)
}
\arguments{
\item{x1}{A \code{smoothbp_fit} object.}

\item{x2}{A \code{smoothbp_fit} object.}

\item{log}{Logical; if TRUE, return log Bayes Factor.}

\item{...}{Passed to \code{\link[bridgesampling]{bridge_sampler}}.}
}
\value{
A numeric value representing the Bayes Factor (or log Bayes Factor if \code{log = TRUE}) comparing \code{x1} to \code{x2}.
}
\description{
Bayes Factor for smoothbp_fit
}
